@@ -169,7 +169,7 @@ def batterystate():
 	
 @cli.command(help='pause the robot')
 def pause():
-    return CliAction('clean', {'act': 'pause'}, wait=StatusWait('vacuum_status', 'pause'))
+    return CliAction('clean', {'act': 'pause'}, wait=StatusWait('vacuum_status', 'STATE_DOCKED'))
 
 @cli.command(help='resume the robot')
 def resume():
@@ -191,30 +191,28 @@ def run(actions, debug):
         config = read_config()
         api = EcoVacsAPI(config['device_id'], config['email'], config['password_hash'],
                          config['country'], config['continent'], verify_ssl=config['verify_ssl'])
+
         vacuum = api.devices()[0]
+
         vacbot = VacBot(api.uid, api.REALM, api.resource, api.user_access_token, vacuum, config['continent'], verify_ssl=config['verify_ssl'])
         
         vacbot.connect_and_wait_until_ready()
 
         for action in actions:
             click.echo("performing " + str(action.vac_command))
-            vacbot.request_all_statuses()
-            vacbot.refresh_liveMap()
-            vacbot.CreatePNGMap()
-            #vacbot.SetFanSpeed('normal')
- 
-            #vacbot.request_all_statuses()
-            #action.wait.wait(vacbot)
-        vacbot.disconnect(wait=True)
+
+            while True:
+                print("aaaa")
+                vacbot.request_all_statuses()
+                print("bbb")
+                print("Battery Status: " + str(vacbot.battery_status), end = '')
+                time.sleep(20)
 		
         for v in vacbot.rooms:
             _LOGGER.debug(v)
 
-        _LOGGER.debug("Battery Status: {}".format(vacbot.battery_status))
-        _LOGGER.debug("Vacuum Status: {}".format(vacbot.vacuum_status))
-        _LOGGER.debug("Fan Speed: {}".format(vacbot.fan_speed))
-        _LOGGER.debug("Image Url: {}".format(vacbot.last_clean_image))
-        _LOGGER.debug("Live Map: {}".format(vacbot.live_map))
+    
+
     click.echo("done")
 
 
